/*   stats.h header for libstats.c         */

#ifndef STATS_LIBRARY
#define STATS_LIBRARY

// constants
#define PI 3.141592654
#define STAT_MAX_LINE_LENGTH 80

#define NSTATS 16

#define NSIGMA 3
#define TOL 0.001
#define MAXITER 20


// macros

#define STIRLING(n) (1.0 + 1.0/(12.0*(n)) + 1.0/(288.0*(n)*(n)) + 139.0/(51840*(n)*(n)*(n)) )

#ifndef DB
#define DB(...) { fprintf(stderr, __VA_ARGS__); }
//#else
//#define DB(...) { }
#endif


/* structures */
typedef struct {
  long n;
  long ndef;
  double sum;
  double mean;
  double meanClip;
  double median;
  double rms;
  double rmsClip;

  double min;
  double min_rms;
  long   min_i;
  double max;
  double max_rms;
  long   max_i;

  double skew;
  double skew_rms;
  double kurt;
  double kurt_rms;

  double all[NSTATS];
} STAT;


/* Functions  */

// max's and mins
long n_defined(double *values, long n);
double max_d(double *values, long n, long *index);
double min_d(double *values, long n, long *index);
long below_d (double *values, long n, double thresh, double *below, long *index, long nMax);
long above_d (double *values, long n, double thresh, double *above, long *index, long nMax);

long window (double *values, long n, double lo, double hi, double *in_range, long *index, long nMax);

// sum
double sum_d(double *values, long n);

// mean and rms  ... median, mode eventually
double mean_d(double *values, long n);
double rms_d(double *values, long n);
double median_d(double *values, long n);

double moment(double *values, long n, long r);
double moment_mean(double *values, long n, long r, double mean);
double skew_d(double *values, long n, double mean, double rms);
double kurt_d(double *values, long n, double mean, double rms);

// routines with sigma clipping
STAT meanRmsClip_d(double *values, long n, double nSigma, double tol, long iter);

double factorial (long N);
double binomCoef (long n, long k);
double binomDist (double p, long t, long n);
double poissonDist (double rate, long n);
double gamma (double n);
double Fdist (double f, long v1, long v2);
double chi2dist (double x2, long v);

void statErrQuit(char *msg, ...);

STAT getStats(double *values, long n);
void getStatNames(char *statname[NSTATS]);



#endif /* STATS_LIBRARY */
