#!/usr/bin/env perl
#
# original filename: writeTimeseries.pl
#
# Steven Bickerton
#  Dept. of Physics/Astronomy, McMaster University
#  bick@physics.mcmaster.ca
#  Made with makeScript, Tue Jul 17, 2007  16:26:59 DST
#  Host: unknown
#  Working Directory: /Users/bick/working/TASS
#


use strict;
use warnings;
use File::Basename;

my $exe = basename($0);
my $usage = "Usage: $exe calfile indfile threshold\n";

my ($calfile, $wsfile, $thresh) = @ARGV;
die $usage unless $thresh && -f $calfile && -f $wsfile;

my $nsigma = $thresh;

sub thresh($$) {
    my ($mag,$nsigma) = @_;
    return 2.0e8*(1.0+2.5*($nsigma))*$mag**(-7.0);
}

# read in the index values
my %variables;
my %index;
open (INDEX, "$wsfile");
while (<INDEX>) {
  next if /^#/;
  my @line = split;
  my ($ID, $mag, $I) = @line[0,4,6];
  if ($I > thresh($mag,$nsigma)) {
      @{$variables{$ID}} = ();
      $index{$ID} = $I;
  }
}
close(INDEX);

# open the calfile and read in the data;
open (IFILE, "$calfile");
while(<IFILE>) {
  next if /^#/;
  my @line = split;
  my ($ID) = $line[0];
  push @{$variables{$ID}}, \@line if defined $variables{$ID};
}
close(IFILE);


my ($ra) = $calfile =~ /i_(\d\d\d).*/;

# print out the time-series
my $tsdir = "ts${ra}";
(-d $tsdir) ? system "rm -r $tsdir/*" : mkdir $tsdir;


 STAR: foreach my $ID (sort {$a<=>$b} keys %variables) {

     my $outfile = $ID;
     my @measurements = @{$variables{$ID}};

     #next STAR if (scalar @star < $n_min);
     
     open (OUT, ">${tsdir}/${outfile}.ts");
     foreach my $ref (sort {$a->[4]<=>$b->[4]} @measurements) {
	 printf OUT "%s %.2f\n", join(" ",@$ref), $index{$ID};
     }
     close (OUT);
 }


exit 0;
